summaryrefslogtreecommitdiff
path: root/extra
diff options
context:
space:
mode:
authorOndrej Bilka <neleai@seznam.cz>2013-07-11 11:57:32 +0400
committerIvan Maidanski <ivmai@mail.ru>2013-07-11 11:59:40 +0400
commitaf453022720d3ae2f0f7ecb0f11029421e553abb (patch)
tree16451cac8bb7e2f5a869fb9a77447208df9a578a /extra
parent5f52b60915bc7effa5d68ea7da8c29584806e9ce (diff)
downloadbdwgc-af453022720d3ae2f0f7ecb0f11029421e553abb.tar.gz
Fix typos in comments
* blacklst.c: Fix typo ("even though"). * cord/cordbscs.c: Fix typo ("exponentially"). * cord/cordxtra.c: Fix typo ("represented"). * dyn_load.c: Fix typos ("uncollectible", "occurred"). * extra/AmigaOS: Fix typos ("specific", "necessary", "always", "effectiveness"). * finalize.c: Fix typo ("descendants"). * include/cord.h: Fix typo ("idiosyncrasies"). * include/gc.h: Fix typo ("collectible"). * include/gc_allocator.h: Fix typos ("allocator", "[un]collectible"). * mach_dep.c: Fix typo ("erroneously"). * malloc.c: Fix typos ("[un]collectible", "pointer-free", "initialization"). * mallocx.c: Fix typos ("largely", "pointer-free", "uncollectible"). * mark.c: Fix typos ("[un]collectible", "even though"). * misc.c: Fix typo ("erroneously"). * os_dep.c: Fix typos ("non-addressable", "happening", "pointer-free"). * tests/test.c: Fix typos ("uncollectible", "reversed"). * tests/test_cpp.cc: Fix typos ("[un]collectible"). * typd_mlc.c: Fix typo ("copyright"). * win32_threads.c: Fix typos ("optimization", "uncollectible").
Diffstat (limited to 'extra')
-rw-r--r--extra/AmigaOS.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/extra/AmigaOS.c b/extra/AmigaOS.c
index 4c747abd..8f99b746 100644
--- a/extra/AmigaOS.c
+++ b/extra/AmigaOS.c
@@ -2,7 +2,7 @@
/******************************************************************
- AmigaOS-spesific routines for GC.
+ AmigaOS-specific routines for GC.
This file is normally included from os_dep.c
******************************************************************/
@@ -230,10 +230,10 @@ void *(*GC_amiga_allocwrapper_do)(size_t size,void *(*AllocFunction)(size_t size
/******************************************************************
- Amiga-spesific routines to obtain memory, and force GC to give
+ Amiga-specific routines to obtain memory, and force GC to give
back fast-mem whenever possible.
These hacks makes gc-programs go many times faster when
- the amiga is low on memory, and are therefore strictly necesarry.
+ the Amiga is low on memory, and are therefore strictly necessary.
-Kjetil S. Matheussen, 2000.
******************************************************************/
@@ -331,7 +331,7 @@ char *chipmax;
/*
- * Allways set to the last size of memory tried to be allocated.
+ * Always set to the last size of memory tried to be allocated.
* Needed to ensure allocation when the size is bigger than 100000.
*
*/
@@ -429,7 +429,7 @@ void *GC_amiga_rec_alloc(size_t size,void *(*AllocFunction)(size_t size2),const
#endif
-/* The allocating-functions defined inside the amiga-blocks in gc.h is called
+/* The allocating-functions defined inside the Amiga-blocks in gc.h is called
* via these functions.
*/
@@ -437,7 +437,7 @@ void *GC_amiga_rec_alloc(size_t size,void *(*AllocFunction)(size_t size2),const
void *GC_amiga_allocwrapper_any(size_t size,void *(*AllocFunction)(size_t size2)){
void *ret,*ret2;
- GC_amiga_dontalloc=TRUE; // Pretty tough thing to do, but its indeed necesarry.
+ GC_amiga_dontalloc=TRUE; // Pretty tough thing to do, but its indeed necessary.
latestsize=size;
ret=(*AllocFunction)(size);
@@ -471,7 +471,7 @@ void *GC_amiga_allocwrapper_any(size_t size,void *(*AllocFunction)(size_t size2)
#ifdef GC_AMIGA_RETRY
else{
/* We got chip-mem. Better try again and again and again etc., we might get fast-mem sooner or later... */
- /* Using gctest to check the effectiviness of doing this, does seldom give a very good result. */
+ /* Using gctest to check the effectiveness of doing this, does seldom give a very good result. */
/* However, real programs doesn't normally rapidly allocate and deallocate. */
// printf("trying to force... %d bytes... ",size);
if(